@@ -1,7 +1,8 @@
 var globals_func =
 [
     [ "e", "globals_func.html", null ],
-    [ "p", "globals_func_p.html", null ],
+    [ "f", "globals_func_f.html", null ],
     [ "r", "globals_func_r.html", null ],
+    [ "s", "globals_func_s.html", null ],
     [ "t", "globals_func_t.html", null ]
 ];
\ No newline at end of file
